#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semialign
version:              1.3.1.1
visibility:           public
id:                   semialign-1.3.1.1-BKB8BqqQqGqD60d6McQxEB
key:                  semialign-1.3.1.1-BKB8BqqQqGqD60d6McQxEB
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  e6824b40eba1de4ced0cce246a273f6d
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/semialign-1.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/semialign-1.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/semialign-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.3.1.1-BKB8BqqQqGqD60d6McQxEB
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    indexed-traversable-instances-0.1.2.1-6tL16kzQI0XASmxmmKiJEL
    semigroupoids-6.0.2-6G0WEN9F3JRKQ3lXmqO9p6
    tagged-0.8.10-9VJfLOM9ch68xR35ePL46j
    these-1.2.1-3rx1V5GanI22DfvaVffCVj
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    vector-0.13.2.0-5a59Ladt6HH20irTaXAFu7

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

